#
# This file is part of Task-BeLike-RSRCHBOY
#
# This software is Copyright (c) 2011 by Chris Weyl.
#
# This is free software, licensed under:
#
#   The GNU Lesser General Public License, Version 2.1, February 1999
#
package Task::BeLike::RSRCHBOY;
our $AUTHORITY = 'cpan:RSRCHBOY';
# git description: 0.006-5-g297f19e
$Task::BeLike::RSRCHBOY::VERSION = '0.007';

# ABSTRACT: Modules RSRCHBOY uses!

!!42;

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::BeLike::RSRCHBOY - Modules RSRCHBOY uses!

=head1 VERSION

version 0.007

=head1 TASK CONTENTS

=head2 CPAN/GitHub Tools

=head3 L<local::lib>

=head3 L<App::cpanminus::reporter>

=head3 L<App::cpanoutdated>

=head3 L<App::gh>

=head3 L<CPAN::Mini>

=head3 L<CPAN::Mini::Inject>

=head3 L<OrePAN2>

=head3 L<Pod::Cpandoc>

=head3 L<Task::CPAN::Reporter>

=head2 DB bits

=head3 L<App::AltSQL>

=head3 L<DBD::SQLite> 1.31

=head3 L<DBIx::Class> 0.08192

=head3 L<DBIx::Class::Schema::Loader> 0.07010

=head3 L<DBIx::Class::Migration>

=head2 Date/Time handling

=head3 L<DateTime>

=head3 L<DateTime::Format::DB2>

=head3 L<DateTime::Format::DBI>

=head3 L<DateTime::Format::MySQL>

=head3 L<DateTime::Format::Pg>

=head2 Hygiene

=head3 L<common::sense>

=head3 L<namespace::autoclean> 0.24

=head3 L<strictures>

=head3 L<Perl::Tidy>

=head3 L<Perl::Critic>

=head2 Class bits

=head3 L<Class::Method::Modifiers::Fast>

=head3 L<Class::Method::Modifiers>

=head3 L<Reindeer> 0.016

=head3 L<MooseX::App::Cmd>

=head3 L<MooseX::AlwaysCoerce>

=head3 L<MooseX::AttributeShortcuts>

=head3 L<MooseX::AutoDestruct> 0.007

=head3 L<MooseX::RelatedClasses>

=head3 L<MooseX::Types::Perl>

=head3 L<MooseX::Types::LoadableClass>

=head3 L<MooseX::Types::Path::Class>

=head3 L<MooseX::Types::Path::Tiny>

=head3 L<Moo>

=head3 L<MooX::Types::MooseLike>

=head3 L<MooX::Cmd>

=head2 Testing

=head3 L<TAP::Harness::Restricted>

=head3 L<Test::Moose::More> 0.017

=head3 L<Test::Routine> 0.015

=head3 L<Test::TempDir::Tiny>

=head2 autobox

=head3 L<autodie> 2.22

=head3 L<autobox::Core>

=head3 L<autobox::dump>

=head3 L<autobox::JSON>

=head3 L<autobox::Colors>

=head2 Other Libraries I Use

=head3 L<aliased>

=head3 L<lib::if::dev>

=head3 L<opts> 0.05

=head3 L<App::Cmd>

=head3 L<Capture::Tiny>

=head3 L<Carp::Always>

=head3 L<Carp::Always::Color>

=head3 L<Config::JFDI>

=head3 L<File::chdir>

=head3 L<Path::Tiny>

=head3 L<Path::Class>

=head3 L<Smart::Args>

=head3 L<Smart::Comments>

=head3 L<Sub::Install>

=head3 L<Sub::Exporter>

=head3 L<Try::Tiny>

=head2 Helpers

=head3 L<Regexp::Debugger>

=head3 L<L>

=head3 L<V>

=head2 CPAN-ish Development

=head3 L<Devel::Confess>

=head3 L<Dist::Zilla::App::Command::cover>

=head3 L<Dist::Zilla::App::Command::issues>

=head3 L<Dist::Zilla::App::Command::gh>

=head3 L<Dist::Zilla::App::Command::dumpwith>

=head3 L<Dist::Zilla::PluginBundle::RSRCHBOY>

=head1 SEE ALSO

Task::BeLike::RSRCHBOY::Web

=head1 AUTHOR

Chris Weyl <cweyl@alumni.drew.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2011 by Chris Weyl.

This is free software, licensed under:

  The GNU Lesser General Public License, Version 2.1, February 1999

=cut
